@@ -24,6 +24,11 @@ class Component(CopyableObject):
             return Button.create(resp)
         elif resp["type"] == ComponentTypes.SELECT_MENU:
             return SelectMenu.create(resp)
+        elif resp["type"] == ComponentTypes.TEXT_INPUT:
+            if "style" not in resp:
+                return TextInputResponse(resp)
+            else:
+                return TextInput.create(resp)
         else:
             raise NotImplementedError
 
@@ -32,6 +37,7 @@ class ComponentTypes(TypeBase):
     ACTION_ROW = 1
     BUTTON = 2
     SELECT_MENU = 3
+    TEXT_INPUT = 4
 
 
 class ActionRow(Component):
@@ -100,7 +106,7 @@ class Button(Component):
         return ret
 
     @classmethod
-    def create(cls, resp):
+    def create(cls, resp: dict):
         return cls(**resp)
 
 
@@ -151,7 +157,7 @@ class SelectMenu(Component):
         return ret
 
     @classmethod
-    def create(cls, resp):
+    def create(cls, resp: dict):
         return cls(**resp)
 
 
@@ -190,10 +196,73 @@ class SelectOption:
         return ret
 
     @classmethod
-    def create(cls, resp):
+    def create(cls, resp: dict):
         return cls(**resp)
 
 
+class TextInput(Component):
+    def __init__(
+        self,
+        *,
+        custom_id: str,
+        style: typing.Union["TextInputStyles", int],
+        label: str = None,
+        min_length: typing.Optional[int] = None,
+        max_length: typing.Optional[int] = None,
+        required: typing.Optional[bool] = None,
+        value: typing.Optional[str] = None,
+        placeholder: typing.Optional[str] = None,
+        **_
+    ):
+        super().__init__(ComponentTypes.TEXT_INPUT)
+        self.custom_id: str = custom_id
+        self.style: TextInputStyles = TextInputStyles(int(style))
+        self.label: str = label
+        self.min_length: typing.Optional[int] = min_length
+        self.max_length: typing.Optional[int] = max_length
+        self.required: typing.Optional[bool] = required
+        self.value: typing.Optional[str] = value
+        self.placeholder: typing.Optional[str] = placeholder
+
+    def to_dict(self) -> dict:
+        ret = {
+            "type": self.type.value,
+            "custom_id": self.custom_id,
+            "style": int(self.style),
+            "label": self.label,
+        }
+        if self.min_length is not None:
+            ret["min_length"] = self.min_length
+        if self.max_length is not None:
+            ret["max_length"] = self.max_length
+        if self.required is not None:
+            ret["required"] = self.required
+        if self.value is not None:
+            ret["value"] = self.value
+        if self.placeholder is not None:
+            ret["placeholder"] = self.placeholder
+        return ret
+
+    @classmethod
+    def create(cls, resp: dict):
+        return cls(**resp)
+
+
+class TextInputResponse:
+    def __init__(self, resp: dict):
+        self.value: str = resp["value"]
+        self.type: ComponentTypes = ComponentTypes(resp["type"])
+        self.custom_id: str = resp["custom_id"]
+
+    def to_dict(self) -> dict:
+        raise AttributeError("unable to dump response")
+
+
+class TextInputStyles(TypeBase):
+    SHORT = 1
+    PARAGRAPH = 2
+
+
 class PartialEmoji:
     def __init__(self, resp: dict):
         self.name: str = resp["name"]
